package controller

import (
	"github.com/gofiber/fiber/v2"
	"github.com/gofiber/swagger"
	"gofiber.study.skcks.cn/common/errorx"
	"gofiber.study.skcks.cn/controller/casbin"
	"gofiber.study.skcks.cn/controller/test"
	"gofiber.study.skcks.cn/controller/user"
	"reflect"
)

func RegisterController(app *fiber.App) {
	controllers := make([]interface{}, 0)
	controllers = append(controllers, user.NewUserController(app))

	for _, controller := range controllers {
		reflectRegisterRoute(controller)
	}

	casbin.RegisterController(app)
	test.RegisterController(app)
}

func reflectRegisterRoute(controller interface{}) {
	t := reflect.ValueOf(controller)
	for i := 0; i < t.NumMethod(); i++ {
		method := t.Method(i)
		args := make([]reflect.Value, 0)
		method.Call(args)
	}
}

// ErrorHandler
//
// @Summary      错误处理
// @Description  错误信息示例
// @Tags         Error
// @Accept       json
// @Produce      json
// @Failure	     default {object}  errorx.CodeErrorResponse
// @Router       /error [get]
// @Router       /error [post]
// @Router       /error [put]
// @Router       /error [delete]
// @Router       /error [patch]
func ErrorHandler(app *fiber.App) {
	app.All("/error", func(ctx *fiber.Ctx) error {
		return ctx.JSON(errorx.NewDefaultError("错误信息示例"))
	})
}

func SwaggerHandler(app *fiber.App) {
	app.Get("/swagger/*", swagger.New(swagger.Config{
		DeepLinking: false,
		// Expand ("list") or Collapse ("none") tag groups by default
		DocExpansion: "list",
	}))
}
